@@ -25,56 +25,54 @@ class DescribeBackupPlanListRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Dbs', '2019-03-06', 'DescribeBackupPlanList','cbs')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ClientToken(self):
+	def get_ClientToken(self): # String
 		return self.get_query_params().get('ClientToken')
 
-	def set_ClientToken(self,ClientToken):
-		self.add_query_param('ClientToken',ClientToken)
-
-	def get_BackupPlanId(self):
+	def set_ClientToken(self, ClientToken):  # String
+		self.add_query_param('ClientToken', ClientToken)
+	def get_BackupPlanId(self): # String
 		return self.get_query_params().get('BackupPlanId')
 
-	def set_BackupPlanId(self,BackupPlanId):
-		self.add_query_param('BackupPlanId',BackupPlanId)
-
-	def get_PageNum(self):
+	def set_BackupPlanId(self, BackupPlanId):  # String
+		self.add_query_param('BackupPlanId', BackupPlanId)
+	def get_PageNum(self): # Integer
 		return self.get_query_params().get('PageNum')
 
-	def set_PageNum(self,PageNum):
-		self.add_query_param('PageNum',PageNum)
+	def set_PageNum(self, PageNum):  # Integer
+		self.add_query_param('PageNum', PageNum)
+	def get_ResourceGroupId(self): # String
+		return self.get_query_params().get('ResourceGroupId')
 
-	def get_OwnerId(self):
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_BackupPlanStatus(self):
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
+	def get_BackupPlanStatus(self): # String
 		return self.get_query_params().get('BackupPlanStatus')
 
-	def set_BackupPlanStatus(self,BackupPlanStatus):
-		self.add_query_param('BackupPlanStatus',BackupPlanStatus)
-
-	def get_BackupPlanName(self):
-		return self.get_query_params().get('BackupPlanName')
-
-	def set_BackupPlanName(self,BackupPlanName):
-		self.add_query_param('BackupPlanName',BackupPlanName)
-
-	def get_PageSize(self):
+	def set_BackupPlanStatus(self, BackupPlanStatus):  # String
+		self.add_query_param('BackupPlanStatus', BackupPlanStatus)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_OwnerId(self): # String
+		return self.get_query_params().get('OwnerId')
 
-	def get_Region(self):
+	def set_OwnerId(self, OwnerId):  # String
+		self.add_query_param('OwnerId', OwnerId)
+	def get_BackupPlanName(self): # String
+		return self.get_query_params().get('BackupPlanName')
+
+	def set_BackupPlanName(self, BackupPlanName):  # String
+		self.add_query_param('BackupPlanName', BackupPlanName)
+	def get_Region(self): # String
 		return self.get_query_params().get('Region')
 
-	def set_Region(self,Region):
-		self.add_query_param('Region',Region)
\ No newline at end of file
+	def set_Region(self, Region):  # String
+		self.add_query_param('Region', Region)
