@@ -25,68 +25,59 @@ class ModifyBackupSetDownloadRulesRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Dbs', '2019-03-06', 'ModifyBackupSetDownloadRules','cbs')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_FullDataFormat(self):
+	def get_FullDataFormat(self): # String
 		return self.get_query_params().get('FullDataFormat')
 
-	def set_FullDataFormat(self,FullDataFormat):
-		self.add_query_param('FullDataFormat',FullDataFormat)
-
-	def get_BackupGatewayId(self):
+	def set_FullDataFormat(self, FullDataFormat):  # String
+		self.add_query_param('FullDataFormat', FullDataFormat)
+	def get_BackupGatewayId(self): # Long
 		return self.get_query_params().get('BackupGatewayId')
 
-	def set_BackupGatewayId(self,BackupGatewayId):
-		self.add_query_param('BackupGatewayId',BackupGatewayId)
-
-	def get_ClientToken(self):
+	def set_BackupGatewayId(self, BackupGatewayId):  # Long
+		self.add_query_param('BackupGatewayId', BackupGatewayId)
+	def get_ClientToken(self): # String
 		return self.get_query_params().get('ClientToken')
 
-	def set_ClientToken(self,ClientToken):
-		self.add_query_param('ClientToken',ClientToken)
-
-	def get_BackupSetDownloadTargetType(self):
+	def set_ClientToken(self, ClientToken):  # String
+		self.add_query_param('ClientToken', ClientToken)
+	def get_BackupSetDownloadTargetType(self): # String
 		return self.get_query_params().get('BackupSetDownloadTargetType')
 
-	def set_BackupSetDownloadTargetType(self,BackupSetDownloadTargetType):
-		self.add_query_param('BackupSetDownloadTargetType',BackupSetDownloadTargetType)
-
-	def get_BackupPlanId(self):
+	def set_BackupSetDownloadTargetType(self, BackupSetDownloadTargetType):  # String
+		self.add_query_param('BackupSetDownloadTargetType', BackupSetDownloadTargetType)
+	def get_BackupPlanId(self): # String
 		return self.get_query_params().get('BackupPlanId')
 
-	def set_BackupPlanId(self,BackupPlanId):
-		self.add_query_param('BackupPlanId',BackupPlanId)
-
-	def get_OwnerId(self):
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_OpenAutoDownload(self):
-		return self.get_query_params().get('OpenAutoDownload')
-
-	def set_OpenAutoDownload(self,OpenAutoDownload):
-		self.add_query_param('OpenAutoDownload',OpenAutoDownload)
-
-	def get_IncrementDataFormat(self):
-		return self.get_query_params().get('IncrementDataFormat')
-
-	def set_IncrementDataFormat(self,IncrementDataFormat):
-		self.add_query_param('IncrementDataFormat',IncrementDataFormat)
-
-	def get_BackupSetDownloadTargetTypeLocation(self):
+	def set_BackupPlanId(self, BackupPlanId):  # String
+		self.add_query_param('BackupPlanId', BackupPlanId)
+	def get_BackupSetDownloadTargetTypeLocation(self): # String
 		return self.get_query_params().get('BackupSetDownloadTargetTypeLocation')
 
-	def set_BackupSetDownloadTargetTypeLocation(self,BackupSetDownloadTargetTypeLocation):
-		self.add_query_param('BackupSetDownloadTargetTypeLocation',BackupSetDownloadTargetTypeLocation)
-
-	def get_BackupSetDownloadDir(self):
+	def set_BackupSetDownloadTargetTypeLocation(self, BackupSetDownloadTargetTypeLocation):  # String
+		self.add_query_param('BackupSetDownloadTargetTypeLocation', BackupSetDownloadTargetTypeLocation)
+	def get_BackupSetDownloadDir(self): # String
 		return self.get_query_params().get('BackupSetDownloadDir')
 
-	def set_BackupSetDownloadDir(self,BackupSetDownloadDir):
-		self.add_query_param('BackupSetDownloadDir',BackupSetDownloadDir)
\ No newline at end of file
+	def set_BackupSetDownloadDir(self, BackupSetDownloadDir):  # String
+		self.add_query_param('BackupSetDownloadDir', BackupSetDownloadDir)
+	def get_OwnerId(self): # String
+		return self.get_query_params().get('OwnerId')
+
+	def set_OwnerId(self, OwnerId):  # String
+		self.add_query_param('OwnerId', OwnerId)
+	def get_OpenAutoDownload(self): # Boolean
+		return self.get_query_params().get('OpenAutoDownload')
+
+	def set_OpenAutoDownload(self, OpenAutoDownload):  # Boolean
+		self.add_query_param('OpenAutoDownload', OpenAutoDownload)
+	def get_IncrementDataFormat(self): # String
+		return self.get_query_params().get('IncrementDataFormat')
+
+	def set_IncrementDataFormat(self, IncrementDataFormat):  # String
+		self.add_query_param('IncrementDataFormat', IncrementDataFormat)
